@@ -8,13 +8,14 @@ import os
 import math as maths
 import numpy as np
 
+import resqpy.derived_model
 import resqpy.fault as rqf
 import resqpy.model as rq
 import resqpy.olio.uuid as bu
 import resqpy.olio.xml_et as rqet
 
-from resqpy.derived_model._common import _displacement_properties, _prepare_simple_inheritance, _write_grid, _establish_model_and_source_grid
-from resqpy.derived_model._copy_grid import copy_grid
+import resqpy.derived_model._common as rqdm_c
+import resqpy.derived_model._copy_grid as rqdm_cg
 
 
 def fault_throw_scaling(epc_file,
@@ -25,7 +26,6 @@ def fault_throw_scaling(epc_file,
                         ref_k0 = 0,
                         ref_k_faces = 'top',
                         cell_range = 0,
-                        offset_decay = 0.5,
                         store_displacement = False,
                         inherit_properties = False,
                         inherit_realization = None,
@@ -49,7 +49,6 @@ def fault_throw_scaling(epc_file,
        ref_k_faces (string, default 'top'): 'top' or 'base' identifying which bounding interface to use as the reference
        cell_range (integer, default 0): the number of cells away from faults which will have depths adjusted to spatially
           smooth the effect of the throw scaling (ie. reduce sudden changes in gradient due to the scaling)
-       offset_decay (float, default 0.5): DEPRECATED; ignored
        store_displacement (boolean, default False): if True, 3 grid property parts are created, one each for x, y, & z
           displacement of cells' centres brought about by the fault throw scaling
        inherit_properties (boolean, default False): if True, the new grid will have a copy of any properties associated
@@ -73,7 +72,6 @@ def fault_throw_scaling(epc_file,
        stretch is towards or away from mid-point of throw;
        same shift is applied to all layers along pillar;
        pillar lines assumed to be straight;
-       the offset decay argument might be changed in a future version to give improved smoothing;
        if a large fault is represented by a series of parallel minor faults 'stepping' down, each minor fault will have the
        scaling factor applied independently, leading to some unrealistic results
     """
@@ -83,7 +81,7 @@ def fault_throw_scaling(epc_file,
         (new_epc_file == epc_file) or
         (os.path.exists(new_epc_file) and os.path.exists(epc_file) and os.path.samefile(new_epc_file, epc_file))):
         new_epc_file = None
-    model, source_grid = _establish_model_and_source_grid(epc_file, source_grid)
+    model, source_grid = rqdm_c._establish_model_and_source_grid(epc_file, source_grid)
     assert source_grid.grid_representation == 'IjkGrid'
     assert model is not None
 
@@ -96,7 +94,7 @@ def fault_throw_scaling(epc_file,
 
     # take a copy of the grid
     log.debug('copying grid')
-    grid = copy_grid(source_grid, model)
+    grid = rqdm_cg.copy_grid(source_grid, model)
     grid.cache_all_geometry_arrays()  # probably already cached anyway
 
     # todo: handle pillars with no geometry defined, and cells without geometry defined
@@ -134,12 +132,12 @@ def fault_throw_scaling(epc_file,
     # build cell displacement property array(s)
     if store_displacement:
         log.debug('generating cell displacement property arrays')
-        displacement_collection = _displacement_properties(grid, source_grid)
+        displacement_collection = rqdm_c._displacement_properties(grid, source_grid)
     else:
         displacement_collection = None
 
-    collection = _prepare_simple_inheritance(grid, source_grid, inherit_properties, inherit_realization,
-                                             inherit_all_realizations)
+    collection = rqdm_c._prepare_simple_inheritance(grid, source_grid, inherit_properties, inherit_realization,
+                                                    inherit_all_realizations)
     if collection is None:
         collection = displacement_collection
     elif displacement_collection is not None:
@@ -161,17 +159,21 @@ def fault_throw_scaling(epc_file,
     # write model
     model.h5_release()
     if new_epc_file:
-        _write_grid(new_epc_file, grid, property_collection = collection, grid_title = new_grid_title, mode = 'w')
+        rqdm_c._write_grid(new_epc_file,
+                           grid,
+                           property_collection = collection,
+                           grid_title = new_grid_title,
+                           mode = 'w')
         epc_file = new_epc_file
     else:
         ext_uuid, _ = model.h5_uuid_and_path_for_node(rqet.find_nested_tags(source_grid.root, ['Geometry', 'Points']),
                                                       'Coordinates')
-        _write_grid(epc_file,
-                    grid,
-                    ext_uuid = ext_uuid,
-                    property_collection = collection,
-                    grid_title = new_grid_title,
-                    mode = 'a')
+        rqdm_c._write_grid(epc_file,
+                           grid,
+                           ext_uuid = ext_uuid,
+                           property_collection = collection,
+                           grid_title = new_grid_title,
+                           mode = 'a')
 
     if len(gcs_list):
         log.debug(f'inheriting grid connection sets related to source grid: {source_grid.uuid}')
@@ -186,7 +188,6 @@ def global_fault_throw_scaling(epc_file,
                                ref_k0 = 0,
                                ref_k_faces = 'top',
                                cell_range = 0,
-                               offset_decay = 0.5,
                                store_displacement = False,
                                inherit_properties = False,
                                inherit_realization = None,
@@ -205,7 +206,6 @@ def global_fault_throw_scaling(epc_file,
        ref_k_faces (string, default 'top'): 'top' or 'base' identifying which bounding interface to use as the reference
        cell_range (integer, default 0): the number of cells away from faults which will have depths adjusted to spatially
           smooth the effect of the throw scaling (ie. reduce sudden changes in gradient due to the scaling)
-       offset_decay (float, default 0.5): DEPRECATED; ignored
        store_displacement (boolean, default False): if True, 3 grid property parts are created, one each for x, y, & z
           displacement of cells' centres brought about by the fault throw scaling
        inherit_properties (boolean, default False): if True, the new grid will have a copy of any properties associated
