@@ -7,13 +7,14 @@ log = logging.getLogger(__name__)
 import numpy as np
 import numpy.ma as ma
 
+import resqpy.grid as grr
 import resqpy.olio.point_inclusion as pip
 import resqpy.olio.uuid as bu
 import resqpy.olio.vector_utilities as vec
 import resqpy.olio.xml_et as rqet
 import resqpy.property as rprop
-from ._defined_geometry import pillar_geometry_is_defined, cell_geometry_is_defined, geometry_defined_for_all_cells, \
-    geometry_defined_for_all_pillars
+import resqpy.weights_and_measures as wam
+import resqpy.grid._defined_geometry as grr_dg
 
 
 def set_cached_points_from_property(grid,
@@ -54,7 +55,7 @@ def set_cached_points_from_property(grid,
        official points array for the grid;
        note that the shape of the points array is quite different between grids with split
        pillars and those without;
-       the uom of the points property must be a length uom and match that used by the grid's crs;
+       the points property values must be in the grid's crs;
        the inactive mask of the grid will only be updated if the set_inactive argument is True;
        if points_property_uuid has been provided, and set_inactive is True, the active property
        must be identified with the active_property_uuid argument;
@@ -85,10 +86,11 @@ def set_cached_points_from_property(grid,
     # check for compatibility and overwrite cached points for grid
     points = rprop.Property(grid.model, uuid = points_property_uuid)
     assert points is not None and points.is_points() and points.indexable_element() == 'nodes'
-    assert points.uom() == grid.xy_units() and grid.z_units() == grid.xy_units()
     points_array = points.array_ref(masked = False)
     assert points_array is not None
     assert points_array.shape == grid.points_cached.shape
+
+    # todo: handle optional points crs and convert to grid crs
     grid.points_cached = points_array
 
     # set grid's time index and series, if requested
@@ -152,12 +154,12 @@ def point_raw(grid, index = None, points_root = None, cache_array = True):
     """
 
     # NB: shape of index depends on whether grid has split pillars
-    if index is not None and not geometry_defined_for_all_pillars(grid, cache_array = cache_array):
+    if index is not None and not grr_dg.geometry_defined_for_all_pillars(grid, cache_array = cache_array):
         if len(index) == 3:
             ji = tuple(index[1:])
         else:
             ji = tuple(divmod(index[1], grid.ni))
-        if ji[0] < grid.nj and not pillar_geometry_is_defined(grid, ji, cache_array = cache_array):
+        if ji[0] < grid.nj and not grr_dg.pillar_geometry_is_defined(grid, ji, cache_array = cache_array):
             return None
     if grid.points_cached is not None:
         if index is None:
@@ -213,8 +215,8 @@ def point(grid, cell_kji0 = None, corner_index = np.zeros(3, dtype = 'int'), poi
         return None
     if grid.k_raw_index_array is None:
         grid.extract_k_gaps()
-    if not geometry_defined_for_all_cells(grid):
-        if not cell_geometry_is_defined(grid, cell_kji0 = cell_kji0, cache_array = cache_array):
+    if not grr_dg.geometry_defined_for_all_cells(grid):
+        if not grr_dg.cell_geometry_is_defined(grid, cell_kji0 = cell_kji0, cache_array = cache_array):
             return None
     p_root = grid.resolve_geometry_child('Points', child_node = points_root)
     #      if p_root is None: return None  # geometry not present
@@ -712,8 +714,8 @@ def corner_points(grid, cell_kji0 = None, points_root = None, cache_resqml_array
 
     def one_cell_cp(grid, cell_kji0, points_root, cache_array):
         cp = np.full((2, 2, 2, 3), np.NaN)
-        if not grid.geometry_defined_for_all_cells():
-            if not grid.cell_geometry_is_defined(cell_kji0, cache_array = cache_array):
+        if not grr_dg.geometry_defined_for_all_cells(grid):
+            if not grr_dg.cell_geometry_is_defined(grid, cell_kji0 = cell_kji0, cache_array = cache_array):
                 return cp
         corner_index = np.zeros(3, dtype = 'int')
         for kp in range(2):
@@ -807,8 +809,8 @@ def corner_points(grid, cell_kji0 = None, points_root = None, cache_resqml_array
                 grid.array_corner_points[:, :, :, 1, 1, 1, :] = points[1:, 1:, 1:, :]
     if cell_kji0 is None:
         return grid.array_corner_points
-    if not geometry_defined_for_all_cells(grid):
-        if not cell_geometry_is_defined(grid, cell_kji0, cache_array = cache_resqml_array):
+    if not grr_dg.geometry_defined_for_all_cells(grid):
+        if not grr_dg.cell_geometry_is_defined(grid, cell_kji0, cache_array = cache_resqml_array):
             return None
     if hasattr(grid, 'array_corner_points'):
         return grid.array_corner_points[tuple(cell_kji0)]
