@@ -751,9 +751,6 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
        the numpy linear algebra option seems to be memory intensive, not recommended
     """
 
-    def z_range(p):
-        return np.nanmax(p[..., 2]) - np.nanmin(p[..., 2])
-
     def best_angles(points, mid_x, mid_y, steps, d_theta):
         best_range = None
         best_x_rotation = None
@@ -766,7 +763,7 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
                 rotation_m = vec.rotation_3d_matrix((x_degrees, 0.0, y_degrees))
                 p = points.copy()
                 rotated_p = vec.rotate_array(rotation_m, p)
-                z_r = z_range(rotated_p)
+                z_r = np.nanmax(rotated_p[..., 2]) - np.nanmin(rotated_p[..., 2])
                 if best_range is None or z_r < best_range:
                     best_range = z_r
                     best_x_rotation = x_degrees
@@ -777,14 +774,13 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
         assert p.ndim >= 2 and p.shape[-1] == 3
         p = p.reshape((-1, 3))
         centre = p.sum(axis = 0) / p.shape[0]
-        u, s, vh = np.linalg.svd(p - centre)
+        _, _, vh = np.linalg.svd(p - centre)
         # unit normal vector
         return vh[2, :]
 
     assert points.ndim >= 2 and points.shape[-1] == 3
 
     if use_linalg:
-
         normal_vector = linalg_normal_vector(points)
         incl = vec.inclination(normal_vector)
         if incl == 0.0:
@@ -792,10 +788,8 @@ def reorient(points, rough = True, max_dip = None, use_linalg = False):
         else:
             azi = vec.azimuth(normal_vector)
             rotation_m = vec.tilt_3d_matrix(azi, incl)
-
     else:
-
-        # coarse iteration trying a few different angles
+        # coarse iteration trying a few different angles
         best_x_rotation, best_y_rotation = best_angles(points, 0.0, 0.0, 7, 30.0)
 
         # finer iteration searching around the best coarse rotation
@@ -837,7 +831,7 @@ def make_all_clockwise_xy(t, p):
     return t
 
 
-def surrounding_xy_ring(p, count = 12, radial_factor = 10.0, radial_distance = None):
+def surrounding_xy_ring(p, count = 12, radial_factor = 10.0, radial_distance = None, inner_ring = False):
     """Creates a set of points surrounding the point set p, in the xy plane.
 
     arguments:
@@ -847,12 +841,23 @@ def surrounding_xy_ring(p, count = 12, radial_factor = 10.0, radial_distance = N
           the 'radius' of the outermost points in p
        radial_distance (float): if present, the radius of the ring of points, unless radial_factor
           results in a greater distance in which case that is used
+       inner_ring (bool, default False): if True, an inner ring of points, with double count, is created
+          at a radius just outside that of the furthest flung original point; this improves triangulation
+          of the extended point set when the original has a non-convex hull
 
     returns:
-       numpy float array of shape (count, 3) being xyz points in surrounding ring; z is set constant to
-       mean value of z in p
+       numpy float array of shape (N, 3) being xyz points in surrounding ring(s); z is set constant to
+       mean value of z in p; N is count if inner_ring is False, 3 * count if True
     """
 
+    def make_ring(count, centre, radius):
+        delta_theta = 2.0 * maths.pi / float(count)
+        ring = np.zeros((count, 3))
+        for i in range(count):
+            theta = float(i) * delta_theta
+            ring[i] = centre + radius * np.array([maths.cos(theta), maths.sin(theta), 0.0])
+        return ring
+
     assert p.shape[-1] == 3
     assert radial_factor >= 1.0
     centre = np.nanmean(p.reshape((-1, 3)), axis = 0)
@@ -861,11 +866,12 @@ def surrounding_xy_ring(p, count = 12, radial_factor = 10.0, radial_distance = N
     radius = p_radius * radial_factor
     if radial_distance is not None and radial_distance > radius:
         radius = radial_distance
-    delta_theta = 2.0 * maths.pi / float(count)
-    ring = np.zeros((count, 3))
-    for i in range(count):
-        theta = float(i) * delta_theta
-        ring[i] = centre + radius * np.array([maths.cos(theta), maths.sin(theta), 0.0])
+    ring = make_ring(count, centre, radius)
+    if inner_ring:
+        inner_radius = p_radius * 1.1
+        assert radius > inner_radius
+        in_ring = make_ring(2 * count, centre, inner_radius)
+        return np.concatenate((in_ring, ring), axis = 0)
     return ring
 
 
@@ -896,6 +902,36 @@ def edges(t):
     return np.unique(all_edges, axis = 0, return_counts = True)
 
 
+def triangles_using_point(t, point_index):
+    """Returns list-like 1D int array of indices of triangles using vertex identified by point_index."""
+
+    assert t.ndim == 2 and t.shape[1] == 3 and isinstance(point_index, int)
+    mask = np.any(t == point_index, axis = -1)
+    return np.where(mask)[0]
+
+
+def triangles_using_edge(t, p1, p2):
+    """Returns list-like 1D int array of indices of triangles using edge identified by pair of point indices."""
+
+    assert t.ndim == 2 and t.shape[1] == 3 and p1 != p2
+    mask = np.logical_and(np.any(t == p1, axis = -1), np.any(t == p2, axis = -1))
+    return np.where(mask)[0]
+
+
+def triangles_using_edges(t, edges):
+    """Returns int array of shape (len(edges), 2) with indices of upto 2 triangles using each edge (-1 for unused)."""
+
+    assert t.ndim == 2 and t.shape[1] == 3 and edges.ndim == 2 and edges.shape[1] == 2
+    ti = np.full((len(edges), 2), -1, dtype = int)
+    for i in range(len(edges)):
+        te = triangles_using_edge(t, edges[i, 0], edges[i, 1])
+        c = len(te)
+        assert 0 <= c <= 2
+        if c:
+            ti[i, :c] = te
+    return ti
+
+
 def rim_edges(all_edges, edge_counts):
     """Returns a subset of all edges where the edge count is 1."""
 
@@ -904,6 +940,14 @@ def rim_edges(all_edges, edge_counts):
     return all_edges[edge_counts == 1, :]
 
 
+def internal_edges(all_edges, edge_counts):
+    """Returns a subset of all edges where the edge count is 2."""
+
+    assert all_edges.ndim == 2 and all_edges.shape[1] == 2
+    assert edge_counts.ndim == 1 and edge_counts.size == len(all_edges)
+    return all_edges[edge_counts == 2, :]
+
+
 def rims(all_rim_edges):
     """Returns edge index and points index lists of distinct rims.
 
@@ -949,7 +993,7 @@ def rims(all_rim_edges):
     return rim_edges_list, rim_points_list
 
 
-@njit
+@njit  # pragma: no cover
 def _find_unused(ap: np.ndarray, used_mask: np.ndarray, v: int):  # type: ignore
     """Finds the first unused occurence of v in pair list ap, returning index and paired value."""
     for idx, val in np.ndenumerate(ap[:, 0]):
@@ -961,18 +1005,18 @@ def _find_unused(ap: np.ndarray, used_mask: np.ndarray, v: int):  # type: ignore
     return ap.shape[0], -1
 
 
-@njit
+@njit  # pragma: no cover
 def _first_false(array: np.ndarray) -> Optional[int]:  # type: ignore
-    """Returns the index of the first False value in the array."""
+    """Returns the index of the first False (or zero) value in the 1D array."""
     for idx, val in np.ndenumerate(array):
         if not val:
             return idx[0]
     return array.size
 
 
-@njit
+@njit  # pragma: no cover
 def _first_match(array: np.ndarray, v: int) -> Optional[int]:  # type: ignore
-    """Returns the index of the first True value in the array."""
+    """Returns the index of the first occurrence of value v in the 1D array."""
     for idx, val in np.ndenumerate(array):
         if val == v:
             return idx[0]
