@@ -1,7 +1,5 @@
 """Class containing resqml stringlookup class."""
 
-version = '24th November 2021'
-
 # Nexus is a registered trademark of the Halliburton Company
 
 import logging
@@ -80,6 +78,11 @@ class StringLookup(BaseResqpy):
         self.max_index = max(self.str_dict.keys())
         self.set_list_from_dict_conditionally()
 
+    def as_dict(self):
+        """Returns the string lookup as a python dictionary."""
+
+        return self.str_dict
+
     def is_equivalent(self, other):
         """Returns True if this lookup is the same as other (apart from uuid); False otherwise."""
 
